## #! /bin/sh
## AUTHOR: Robert Twyman
## AUTHOR: Kris Thielemans
## Copyright (C) 2020 University College London
## Licensed under the Apache License, Version 2.0

## This script estimates the background randoms from Delayed coincidences.

## PARAMETERS

set -e # exit on error
trap "echo ERROR in $0" ERR

if [ $# != 2 ]; then
	echo "Usage: EstimateGATESTIRNorm.sh OutputFilename DelayedData"
	exit 1
fi 

set -e # exit on error
trap "echo ERROR in $0" ERR

OutputFilename=$1 
DelayedData=$2 ## Delayed Coincidences Sinogram

## factors are the norm_filename_prefix generated by find_ML_normfactors3D and input for apply_normfactors3D
factors=randoms_factors

## loop numbers
eff_iters=10

## create ones sino
echo "stir_math"
stir_math -s --including-first --times-scalar 0 --add-scalar 1 ones.hs $DelayedData


## find ML normfactors
echo "find_ML_normfactors3D"
find_ML_normfactors3D $factors $DelayedData ones.hs 0 $eff_iters


## mutiply ones with the norm factors to get a sino
echo "apply_normfactors3D"
apply_normfactors3D $OutputFilename $factors ones.hs 1 1 $eff_iters


## Delete ones sinogram
rm ones.hs
rm ones.s
